@@ -12,10 +12,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -127,7 +127,7 @@ tvit_initialize_trash_dir (const gchar *trash_dir)
   gboolean     result = FALSE;
   gchar       *files_dir;
   gchar       *info_dir;
-  gchar       *basename;
+  gchar       *base_name;
   gchar       *dirname;
   GDir        *dp;
 
@@ -151,16 +151,16 @@ tvit_initialize_trash_dir (const gchar *trash_dir)
               if (G_LIKELY (dp != NULL))
                 {
                   /* determine the basename to look for */
-                  basename = g_path_get_basename (trash_dir);
+                  base_name = g_path_get_basename (trash_dir);
                   do
                     {
                       /* compare the next entry */
                       name = g_dir_read_name (dp);
                       if (G_LIKELY (name != NULL))
-                        result = (strcmp (name, basename) == 0);
+                        result = (strcmp (name, base_name) == 0);
                     }
                   while (name != NULL && !result);
-                  g_free (basename);
+                  g_free (base_name);
                 }
               g_free (dirname);
 
@@ -1172,7 +1172,7 @@ _thunar_vfs_io_trash_get_metadata (ThunarVfsPath        *path,
 
   _thunar_vfs_return_val_if_fail (_thunar_vfs_path_is_trash (path), NULL);
   _thunar_vfs_return_val_if_fail (error == NULL || *error == NULL, NULL);
-  
+
   switch (metadata)
     {
     case THUNAR_VFS_INFO_METADATA_FILE_LINK_TARGET:
@@ -1369,7 +1369,7 @@ _thunar_vfs_io_trash_copy_file (ThunarVfsPath                 *source_path,
           if (G_UNLIKELY (!succeed))
             {
               /* drop the file from the trash and release the target path */
-              if (!_thunar_vfs_io_trash_remove (target_path, NULL)) 
+              if (!_thunar_vfs_io_trash_remove (target_path, NULL))
                 g_warning ("Failed to remove stale trash handle %s in %u", file_id, trash_id);
               thunar_vfs_path_unref (target_path);
             }
@@ -1484,7 +1484,7 @@ _thunar_vfs_io_trash_move_file (ThunarVfsPath  *source_path,
           if (G_UNLIKELY (!succeed))
             {
               /* drop the file from the trash and release the target path */
-              if (!_thunar_vfs_io_trash_remove (target_path, NULL)) 
+              if (!_thunar_vfs_io_trash_remove (target_path, NULL))
                 g_warning ("Failed to remove stale trash handle %s in %u", file_id, trash_id);
               thunar_vfs_path_unref (target_path);
             }
