@@ -12,10 +12,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -412,7 +412,7 @@ thunar_vfs_thumb_factory_cache_load (ThunarVfsThumbFactory *factory,
 {
   struct stat statb;
   gssize      m;
-  gsize       n;
+  gssize      n;
   gint        fd;
 
   _thunar_vfs_return_if_fail (THUNAR_VFS_IS_THUMB_FACTORY (factory));
@@ -549,7 +549,7 @@ thunar_vfs_thumb_factory_cache_monitor (ThunarVfsMonitor       *monitor,
     {
       /* determine the thumbnailers.cache file */
       cache_file = thunar_vfs_path_dup_string (handle_path);
-      
+
       /* the thumbnailers.cache file was changed, reload it */
       g_mutex_lock (factory->cache_lock);
       thunar_vfs_thumb_factory_cache_unload (factory);
