@@ -12,10 +12,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /********************************************************************************
@@ -431,14 +431,14 @@ thumbnailers_load_custom (GHashTable *thumbnailers)
       mime_types = xfce_rc_read_list_entry (rc, "MimeType", ";");
       if (G_UNLIKELY (mime_types == NULL))
         continue;
-      
+
       /* process all specified mime types */
       for (m = 0; mime_types[m] != NULL; ++m)
         {
           /* check if we have a valid mime type here */
           if (strlen (mime_types[m]) > 0 && strstr (mime_types[m], "/") != NULL)
             {
-              /* set our thumbnailer for all those mime types (don't need to 
+              /* set our thumbnailer for all those mime types (don't need to
                * duplicate the exec string, because we leave the RC file open).
                */
               g_hash_table_insert (thumbnailers, mime_types[m], (gchar *) exec);
@@ -458,7 +458,7 @@ thumbnailers_needs_update (const gchar  *filename,
   gboolean    needs_update;
   gssize      m;
   gchar      *contents;
-  gsize       n;
+  gssize      n;
   gint        fd;
 
   /* try to open the file */
