@@ -12,10 +12,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Library General
+ * Public License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -398,7 +398,7 @@ thunar_vfs_volume_hal_update (ThunarVfsVolumeHal *volume_hal,
 {
   gchar *desired_mount_point;
   gchar *mount_root;
-  gchar *basename;
+  gchar *base_name;
   gchar *filename;
 
   _thunar_vfs_return_if_fail (THUNAR_VFS_IS_VOLUME_HAL (volume_hal));
@@ -533,7 +533,7 @@ thunar_vfs_volume_hal_update (ThunarVfsVolumeHal *volume_hal,
    * a drive, which means non-pollable then, so it's present
    */
   volume_hal->status |= THUNAR_VFS_VOLUME_STATUS_PRESENT;
-  
+
   /* figure out if the volume is mountable */
   if(hv != NULL && libhal_volume_get_fsusage (hv) == LIBHAL_VOLUME_USAGE_MOUNTABLE_FILESYSTEM)
     volume_hal->status |= THUNAR_VFS_VOLUME_STATUS_MOUNTABLE;
@@ -594,11 +594,11 @@ thunar_vfs_volume_hal_update (ThunarVfsVolumeHal *volume_hal,
       if (G_UNLIKELY (volume_hal->mount_point == NULL))
         {
           /* <mount-root>/<device> looks like a good idea */
-          basename = g_path_get_basename (volume_hal->device_file);
-          filename = g_build_filename (mount_root, basename, NULL);
+          base_name = g_path_get_basename (volume_hal->device_file);
+          filename = g_build_filename (mount_root, base_name, NULL);
           volume_hal->mount_point = thunar_vfs_path_new (filename, NULL);
           g_free (filename);
-          g_free (basename);
+          g_free (base_name);
         }
 
       /* release the mount root */
@@ -838,7 +838,7 @@ thunar_vfs_volume_manager_hal_init (ThunarVfsVolumeManagerHal *manager_hal)
                     {
                       /* add the volume based on the UDI */
                       thunar_vfs_volume_manager_hal_device_added (manager_hal->context, udis[n]);
-                      
+
                       /* release the UDI (HAL bug #5279) */
                       free (udis[n]);
                     }
